@@ -24,18 +24,21 @@
 
 """Top-level package for enpt_enmapboxapp."""
 
+import os as __os
+
 from .version import __version__, __versionalias__   # noqa (E402 + F401)
-from .enpt_algorithm import EnPTAlgorithm
-from .enpt_external_algorithm import ExternalEnPTAlgorithm
-from .enpt_enmapboxapp import EnPTEnMAPBoxApp
 
 __author__ = """Daniel Scheffler"""
 __email__ = 'danschef@gfz-potsdam.de'
 __all__ = ['__version__',
            '__versionalias__',
            '__author__',
-           '__email__',
-           'EnPTAlgorithm',
-           'ExternalEnPTAlgorithm',
-           'EnPTEnMAPBoxApp'
+           '__email__'
            ]
+
+
+# $PROJ_LIB was renamed to $PROJ_DATA in proj=9.1.1, which leads to issues with fiona>=1.8.20,<1.9
+# https://github.com/conda-forge/pyproj-feedstock/issues/130
+# -> fix it by setting PROJ_DATA
+if 'GDAL_DATA' in __os.environ and 'PROJ_DATA' not in __os.environ and 'PROJ_LIB' not in __os.environ:
+    __os.environ['PROJ_DATA'] = __os.path.join(__os.path.dirname(__os.environ['GDAL_DATA']), 'proj')
