@@ -75,6 +75,7 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
     P_path_reference_image = 'path_reference_image'
     P_enable_ac = 'enable_ac'
     P_mode_ac = 'mode_ac'
+    P_polymer_additional_results = 'polymer_additional_results'
     P_polymer_root = 'polymer_root'
     P_threads = 'threads'
     P_blocksize = 'blocksize'
@@ -311,6 +312,12 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
                          'combined - SICOR is applied to land and POLYMER to water'],
                 defaultValue=2))
 
+        self.addParameter(
+            QgsProcessingParameterBoolean(
+                name=self.P_polymer_additional_results,
+                description="Enable generation of additional results from ACwater/POLYMER (if executed)",
+                defaultValue=True))
+
         self.addParameter(
             QgsProcessingParameterFile(
                 name=self.P_polymer_root,
@@ -362,15 +369,15 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
         self.addParameter(
             QgsProcessingParameterBoolean(
                 name=self.P_run_deadpix_P,
-                description='Dead pixel correction',
-                defaultValue=True))
+                description='Dead pixel correction (based on L1B dead pixel map)',
+                defaultValue=False))
 
         self.addParameter(
             QgsProcessingParameterEnum(
                 name=self.P_deadpix_P_algorithm,
                 description="Algorithm for dead pixel correction",
                 options=['spectral', 'spatial'],
-                defaultValue=0),
+                defaultValue=1),
             advanced=True)
 
         self.addParameter(
